* Set the maximum number of variables in a model to 10,000
set matsize 10000

* Set up the panel
xtset ccode year

* Create variables of interest
gen y=ln(gdp)
gen dy=d.y
gen p=ln(cpi)
gen dp=d.p
gen gd=ln(gdebt)
gen dgd=d.gd


* Create cross-sectional (cs) averages
xtset year ccode

bys year: egen dybar=mean(dy)
bys year: egen dpbar=mean(dp)
bys year: egen dgdbar=mean(dgd)

xtset ccode year

* Create lagged values of the cs averages
gen ldybar=l.dybar
gen l2dybar=l2.dybar
gen l3dybar=l3.dybar

gen ldpbar=l.dpbar
gen l2dpbar=l2.dpbar
gen l3dpbar=l3.dpbar

gen ldgdbar=l.dgdbar
gen l2dgdbar=l2.dgdbar
gen l3dgdbar=l3.dgdbar

* Create the lagged values of the variables
gen ldp=l.dp 
gen ldgd=l.dgd


* Create the changes in the variables and their lags
gen ddp=d.dp 
gen lddp=ld.dp 
gen l2ddp=l2d.dp 
gen l3ddp=l3d.dp 

gen ddgd=d.dgd 
gen lddgd=ld.dgd 
gen l2ddgd=l2d.dgd 
gen l3ddgd=l3d.dgd 


* Create the threshold dummy for different Debt/GDP levels
gen d30=0 
gen d40=0 
gen d50=0 
gen d60=0
gen d70=0
gen d80=0
gen d90=0

replace d30=1 if gdebt>=30
replace d40=1 if gdebt>=40
replace d50=1 if gdebt>=50
replace d60=1 if gdebt>=60
replace d70=1 if gdebt>=70
replace d80=1 if gdebt>=80
replace d90=1 if gdebt>=90

replace d30=. if missing(gdebt)
replace d40=. if missing(gdebt)
replace d50=. if missing(gdebt)
replace d60=. if missing(gdebt)
replace d70=. if missing(gdebt)
replace d80=. if missing(gdebt)
replace d90=. if missing(gdebt)


* Create the interaction term for positive values of Debt/GDP growth
gen dgdplus=max(0,dgd)
replace dgdplus=. if missing(gdebt)

gen dgdpd30=dgdplus*d30
gen dgdpd40=dgdplus*d40
gen dgdpd50=dgdplus*d50
gen dgdpd60=dgdplus*d60
gen dgdpd70=dgdplus*d70
gen dgdpd80=dgdplus*d80
gen dgdpd90=dgdplus*d90


* Find out which countries have positive values for the threshold dummies
bys ccode: egen d30use=sum(d30) 
bys ccode: egen d40use=sum(d40) 
bys ccode: egen d50use=sum(d50) 
bys ccode: egen d60use=sum(d60) 
bys ccode: egen d70use=sum(d70) 
bys ccode: egen d80use=sum(d80) 
bys ccode: egen d90use=sum(d90) 

*** stop here please ***
stop

************* ARDL Regressions (ECM Specification) ************* 
* The below will give the results in Table 15 and 16: to obtain the MG results type 'mg' after 'replace' and to obtain the FE results type 'dfe cluster(ccode)' after 'replace'

**** ARDL of Order 1 ****
xtpmg d.dy d.dp       , lr(l.dy dp    ) replace mg
xtpmg d.dy      d.dgd , lr(l.dy    dgd) replace mg
xtpmg d.dy d.dp d.dgd , lr(l.dy dp dgd) replace mg

**** ARDL of Order 2 ****
xtpmg d.dy ld.dy d.dp ld.dp             , lr(l.dy dp     ) replace mg
xtpmg d.dy ld.dy           d.dgd ld.dgd , lr(l.dy     dgd) replace mg
xtpmg d.dy ld.dy d.dp ld.dp d.dgd ld.dgd , lr(l.dy dp dgd) replace mg

**** ARDL of order 3 ****
xtpmg d.dy ld.dy l2d.dy d.dp ld.dp l2d.dp                      , lr(l.dy dp    ) replace mg
xtpmg d.dy ld.dy l2d.dy                   d.dgd ld.dgd l2d.dgd , lr(l.dy    dgd) replace mg
xtpmg d.dy ld.dy l2d.dy d.dp ld.dp l2d.dp d.dgd ld.dgd l2d.dgd , lr(l.dy dp dgd) replace mg


************* Cross-Sectionally Augmented ARDL (CS-ARDL) Regressions (ECM Specification) ************* 
* The below will give the results in Table 17

**** ARDL of Order 1 ****
xtpmg d.dy d.dp                                                dybar dpbar        ldybar ldpbar         l2dybar l2dpbar          l3dybar l3dpbar         , lr(l.dy     dp) replace mg
xtpmg d.dy      d.dgd                                          dybar       dgdbar ldybar        ldgdbar l2dybar         l2dgdbar l3dybar         l3dgdbar, lr(l.dy dgd   ) replace mg
xtpmg d.dy d.dp d.dgd                                          dybar dpbar dgdbar ldybar ldpbar ldgdbar l2dybar l2dpbar l2dgdbar l3dybar l3dpbar l3dgdbar, lr(l.dy dgd dp) replace mg

**** ARDL of Order 2 ****
xtpmg d.dy ld.dy d.dp ld.dp                                    dybar dpbar        ldybar ldpbar         l2dybar l2dpbar          l3dybar l3dpbar         , lr(l.dy     dp) replace mg
xtpmg d.dy ld.dy            d.dgd ld.dgd                       dybar       dgdbar ldybar        ldgdbar l2dybar         l2dgdbar l3dybar         l3dgdbar, lr(l.dy dgd   ) replace mg
xtpmg d.dy ld.dy d.dp ld.dp d.dgd ld.dgd                       dybar dpbar dgdbar ldybar ldpbar ldgdbar l2dybar l2dpbar l2dgdbar l3dybar l3dpbar l3dgdbar, lr(l.dy dgd dp) replace mg

**** ARDL of order 3 ****
xtpmg d.dy ld.dy l2d.dy d.dp ld.dp l2d.dp                      dybar dpbar        ldybar ldpbar         l2dybar l2dpbar          l3dybar l3dpbar         , lr(l.dy     dp) replace mg
xtpmg d.dy ld.dy l2d.dy                   d.dgd ld.dgd l2d.dgd dybar       dgdbar ldybar        ldgdbar l2dybar         l2dgdbar l3dybar         l3dgdbar, lr(l.dy dgd   ) replace mg
xtpmg d.dy ld.dy l2d.dy d.dp ld.dp l2d.dp d.dgd ld.dgd l2d.dgd dybar dpbar dgdbar ldybar ldpbar ldgdbar l2dybar l2dpbar l2dgdbar l3dybar l3dpbar l3dgdbar, lr(l.dy dgd dp) replace mg


************* Cross-Sectionally Augmented Distributed Lag (CS-DL) Regressions *************
* The below will give the results in Table 18

*** MG estimations with Debt/GDP Growth and Inflation ***
xtmg dy ldgd ldp ddp ddgd                         dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar  
xtmg dy ldgd ldp ddp ddgd lddp lddgd              dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar  
xtmg dy ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar 


*** MG estimations with just Inflation ***
xtmg dy ldp ddp            dybar dpbar ldpbar l2dpbar l3dpbar
xtmg dy ldp ddp lddp       dybar dpbar ldpbar l2dpbar l3dpbar 
xtmg dy ldp ddp lddp l2ddp dybar dpbar ldpbar l2dpbar l3dpbar


*** MG estimations with just Debt/GDP Growth *** 
xtmg dy ldgd ddgd              dybar dgdbar ldgdbar l2dgdbar l3dgdbar 
xtmg dy ldgd ddgd lddgd        dybar dgdbar ldgdbar l2dgdbar l3dgdbar 
xtmg dy ldgd ddgd lddgd l2ddgd dybar dgdbar ldgdbar l2dgdbar l3dgdbar 


************* Threshold Analysis ************* 
* The below will give the results in Tables 20-21

*** Step (i): Pooled OLS regressions ***
regress dy d30 , vce(robust)
regress dy d40 , vce(robust)
regress dy d50 , vce(robust)
regress dy d60 , vce(robust)
regress dy d70 , vce(robust)
regress dy d80 , vce(robust)
regress dy d90 , vce(robust)

*** Step (ii): MG regressions ***
xtmg dy d30 if d30use>=1 & d30use<=44 & ccode!=4 & ccode!=20 & ccode!=29 
xtmg dy d40 if d40use>=1              & ccode!=4                         
xtmg dy d50 if d50use>=1              & ccode!=4                         
xtmg dy d60 if d60use>=1                                                 
xtmg dy d70 if d70use>=1                                                 
xtmg dy d80 if d80use>=1												 
xtmg dy d90 if d90use>=1 												 

*** Step (iii): CS-DL MG regressions with threshold dummy ***
xtmg dy d30     ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d30use>=1 & d30use<=44 & ccode!=4 & ccode!=20 & ccode!=29  
xtmg dy d40     ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d40use>=1   & ccode!=2 & ccode!=4                          
xtmg dy d50     ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d50use>=1              & ccode!=4                          
xtmg dy d60     ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d60use>=1                                                  
xtmg dy d70     ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d70use>=1                                                  
xtmg dy d80     ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d80use>=1  & ccode!=38                                     
xtmg dy d90     ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d90use>=1                                                  

*** Step (iv): CS-DL MG regressions with threshold dummy and interactive threshold effects ***
xtmg dy d30 dgdpd30 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d30use>=1 & d30use<=44 & ccode!=2 & ccode!=8 & ccode!=4 & ccode!=20 & ccode!=29 
xtmg dy d40 dgdpd40 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d40use>=1 & ccode!=2 & ccode!=4 & ccode!=8 & ccode!=35 
xtmg dy d50 dgdpd50 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d50use>=1 & ccode!=4 
xtmg dy d60 dgdpd60 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d60use>=1 
xtmg dy d70 dgdpd70 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d70use>=1 & ccode!=3 & ccode!=24 & ccode!=36  
xtmg dy d80 dgdpd80 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d80use>=1 & ccode!=38   
xtmg dy d90 dgdpd90 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d90use>=1  

*** Step (v): CS-DL MG regressions with interactive threshold effects ***
xtmg dy dgdpd30 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d30use>=1 & ccode!=2   
xtmg dy dgdpd40 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d40use>=1 & ccode!=2   
xtmg dy dgdpd50 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d50use>=1              
xtmg dy dgdpd60 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d60use>=1              
xtmg dy dgdpd70 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d70use>=1              
xtmg dy dgdpd80 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d80use>=1 & ccode!=38  
xtmg dy dgdpd90 ldgd ldp ddp ddgd lddp lddgd l2ddp l2ddgd dybar dpbar dgdbar ldpbar ldgdbar l2dpbar l2dgdbar l3dpbar l3dgdbar if d90use>=1              
